%This matlab file reads the data generated by the Analysis Sequences
%in the DemoModels and plots the comparisons between Coustyx results 
%and Analytical results.

%********************************************************************
%Compare results from coustyx and analytical solutions for 
%Plane wave scattered by a rigid sphere

%********************************************************************
%Input:
%  Run the following Analysis Sequences in the Demo Model,
%  before running this matlab script. 
%   (1) RunValidation - FMM
%********************************************************************
resultsFMM = load('validation_results_fmm.txt');

%  Each *.txt results file has 5 columns, where
%    results(:,1) = theta, 0<=theta<=2PI
%    results(:,2) = Real part of coustyx field point pressure
%    results(:,3) = Imaginary part of coustyx field point pressure
%    results(:,4) = Real part of analytical pressure
%    results(:,5) = Imaginary part of analytical pressure

%********************************************************************

%********************************************************************
%Output:
%  (1) plot 1: Plots comparisons between FMM and Analytical results
%********************************************************************

%Acoustic medium properties:
%  rho_o = medium density of air = 1.21 kg.m^3
%  c = speed of sound = 343 m/s
%  P0 = amplitude of the incident plane wave = 1 pa
rho_o = 1.21;
c = 343;
u0 = 1;
P0 = 1;

%********************************************************************
xfmm = (abs(resultsFMM(:,2)+i*resultsFMM(:,3)).*cos(resultsFMM(:,1)))/P0;
yfmm = (abs(resultsFMM(:,2)+i*resultsFMM(:,3)).*sin(resultsFMM(:,1)))/P0;
xanaly = (abs(resultsFMM(:,4)+i*resultsFMM(:,5)).*cos(resultsFMM(:,1)))/P0;
yanaly = (abs(resultsFMM(:,4)+i*resultsFMM(:,5)).*sin(resultsFMM(:,1)))/P0;
xref = cos(resultsFMM(:,1));
yref = sin(resultsFMM(:,1));

%********************************************************************
% Plot FMM and Analytical results on a plot showing angular 
% distribution of pressure amplitudes.
% Note the radius at any point on the graph is equal to the amplitude
% of p_total/p_incident.
%********************************************************************
figure;
plot(xfmm, yfmm, 'r-', xanaly, yanaly, 'b.', xref, yref, 'k--');
legend('Coustyx-FMM','Analytical','Incident Wave');
title('Field point pressures - Amplitude at r=1.5');

% matFMM = [xfmm yfmm xanaly yanaly xref yref];
% save results_abs_fmm_ka4.txt matFMM -ASCII







